<?php
/**
 * Simple Stripe Payment
 *
 * @package    Simple Stripe Payment
 * @subpackage SimpleStripePayment Main Functions
/*  Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$simplestripepayment = new SimpleStripePayment();

/** ==================================================
 * Class Main function
 *
 * @since 1.00
 */
class SimpleStripePayment {

	/** ==================================================
	 * Attributes
	 *
	 * @var $simplepaypalpayment_atts  attributes.
	 */
	private $simplestripepayment_atts;

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'wp_footer', array( $this, 'load_localize_scripts_styles' ) );
		add_action( 'admin_footer', array( $this, 'load_localize_scripts_styles' ) );
		add_action( 'init', array( $this, 'simplestripepayment_block_init' ) );

	}

	/** ==================================================
	 * Attribute block
	 *
	 * @since 1.00
	 */
	public function simplestripepayment_block_init() {

		wp_register_script(
			'simplestripepayment-block',
			plugins_url( 'js/simplestripepayment-block.js', dirname( __FILE__ ) ),
			array( 'wp-blocks', 'wp-element', 'wp-components', 'wp-editor' ),
			'1.00',
			true
		);

		$simplestripepayment_settings = get_option( 'simplestripepayment_settings' );
		register_block_type(
			'stripe-button/simplestripepayment-block',
			array(
				'attributes'      => array(
					'amount'      => array(
						'type'    => 'string',
						'default' => $simplestripepayment_settings['amount'],
					),
					'name'        => array(
						'type'    => 'string',
						'default' => $simplestripepayment_settings['name'],
					),
					'description' => array(
						'type'    => 'string',
						'default' => $simplestripepayment_settings['description'],
					),
					'currency'    => array(
						'type'    => 'string',
						'default' => $simplestripepayment_settings['currency'],
					),
					'label'       => array(
						'type'    => 'string',
						'default' => $simplestripepayment_settings['label'],
					),
					'before'      => array(
						'type'    => 'string',
						'default' => html_entity_decode( $simplestripepayment_settings['before'] ),
					),
					'after'       => array(
						'type'    => 'string',
						'default' => html_entity_decode( $simplestripepayment_settings['after'] ),
					),
					'remove'      => array(
						'type'    => 'string',
						'default' => html_entity_decode( $simplestripepayment_settings['remove'] ),
					),
				),
				'editor_script'   => 'simplestripepayment-block',
				'render_callback' => array( $this, 'simplestripepayment_func' ),
			)
		);

		add_shortcode( 'simplestripepayment', array( $this, 'simplestripepayment_func' ) );

	}

	/** ==================================================
	 * Load Localize Script and Style
	 *
	 * @since 1.00
	 */
	public function load_localize_scripts_styles() {

		$localize_ssp_settings = array();
		if ( is_singular() || is_admin() ) {
			$localize_ssp_settings = $this->simplestripepayment_atts;
		} else { /* for widget */
			if ( ( is_archive() || is_home() ) && is_active_widget( false, false, 'simplestripepaymentwidgetitem', true ) ) {
				$localize_ssp_settings = get_option( 'simplestripepayment_settings' );
			} else {
				return;
			}
		}
		if ( empty( $localize_ssp_settings ) ) {
			return;
		}

		/* Zero-decimal currencies */
		$zero_decimal_curr = array( 'MGA', 'BIF', 'CLP', 'PYG', 'DJF', 'RWF', 'GNF', 'UGX', 'VND', 'JPY', 'VUV', 'XAF', 'KMF', 'KRW', 'XOF', 'XPF' );
		if ( ! in_array( $localize_ssp_settings['currency'], $zero_decimal_curr, true ) ) {
			$localize_ssp_settings['amount'] = intval( $localize_ssp_settings['amount'] * 100 );
		}

		wp_enqueue_style( 'stripe', plugin_dir_url( __DIR__ ) . 'css/stripebutton.css', array(), '1.0.0', 'all' );
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'stripe', 'https://checkout.stripe.com/checkout.js', array(), '1.0.0', false );

		$stripe_settings = get_option( 'simplestripepayment_ids' );
		require_once dirname( __FILE__ ) . '/class-simplestripepaymentadmin.php';
		$simplestripepaymentadmin = new SimpleStripePaymentAdmin();
		if ( $stripe_settings['test'] ) {
			$public_key = $simplestripepaymentadmin->decrypt( $stripe_settings['test_data_key'] );
		} else {
			$public_key = $simplestripepaymentadmin->decrypt( $stripe_settings['data_key'] );
		}
		$public_key_arr = array( 'public_key' => $public_key );
		unset( $simplestripepaymentadmin );
		$localize_ssp_settings = array_merge( $localize_ssp_settings, $public_key_arr );

		$handle  = 'simple-stripe-payment-ajax-script';
		$action1 = 'simple-stripe-payment-charge-ajax-action';
		wp_enqueue_script( $handle, plugin_dir_url( __DIR__ ) . 'js/jquery.simplestripepayment.js', array( 'jquery' ), '1.0.0', false );
		$ajax_arr = array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'action'   => $action1,
			'nonce'    => wp_create_nonce( $action1 ),
		);

		$ajax_arr = array_merge( $ajax_arr, $localize_ssp_settings );
		wp_localize_script( $handle, 'SIMPLESTRIPEPAYMENTCHARGE', $ajax_arr );

	}

	/** ==================================================
	 * Short code
	 *
	 * @param  array  $atts    atts.
	 * @param  string $content content.
	 * @return string $content content.
	 * @since 1.00
	 */
	public function simplestripepayment_func( $atts, $content = null ) {

		$a = shortcode_atts(
			array(
				'amount'      => '',
				'name'        => '',
				'description' => '',
				'currency'    => '',
				'label'       => '',
				'before'      => '',
				'after'       => '',
				'remove'      => '',
				'remove2'     => '',
				'email'       => '',
				'payname'     => '',
			),
			$atts
		);

		$settings_tbl = get_option( 'simplestripepayment_settings' );

		foreach ( $settings_tbl as $key => $value ) {
			$shortcodekey = strtolower( $key );
			if ( empty( $a ) ) {
				$atts                  = array();
				$atts[ $shortcodekey ] = $value;
			} else {
				if ( ! array_key_exists( $shortcodekey, $atts ) ) {
					$atts[ $shortcodekey ] = $value;
				} else {
					if ( strtolower( $atts[ $shortcodekey ] ) === 'false' ) {
						$atts[ $shortcodekey ] = null;
					}
				}
			}
		}

		$this->simplestripepayment_atts = $atts;

		if ( is_singular() || is_admin() ) {
			if ( ! empty( $atts['before'] ) ) {
				$before_text = $atts['before'];
			} else {
				$before_text = null;
			}
			$content = '<div class="simple_stripe_payment_before">' . $before_text . '</div><span class="simple_stripe_payment_after"></span><button id="SPPcustomButton" class="stripe_btn">' . $atts['label'] . '</button>';
		} else {
			if ( is_archive() || is_home() ) {
				$content = null;
			} else {
				$content = __( 'It is not displayed on the edit screen. Please preview.', 'simple-stripe-payment' );
			}
		}

		return do_shortcode( $content );

	}

}


